@@ -3,8 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef KDECORATION2_DECORATION_P_H
-#define KDECORATION2_DECORATION_P_H
+#pragma once
 #include "decoration.h"
 
 //
@@ -56,5 +55,3 @@ private:
 };
 
 } // namespace
-
-#endif
